import os
import logging
import pathlib

import daiquiri

LOGDIR = pathlib.Path.home() / '.logs'


def Logger(name=None, level=logging.INFO):
    if not LOGDIR.exists():
        LOGDIR.mkdir(parents=True)

    daiquiri.setup(outputs=(
        daiquiri.output.STDERR,
        daiquiri.output.File(directory=LOGDIR)
    ), level=level)

    logger = daiquiri.getLogger(name)

    if os.getenv('DEBUG'):
        logger.setLevel(logging.DEBUG)

    return logger



import shutil
import inspect
import pathlib

import toml
import addict
from first import first

CONFIGDIR = pathlib.Path.home() / '.config'


def get_caller_path():
    stack = inspect.stack()
    try:
        frame = first(stack, key=lambda frame: 'kick.' in (frame.code_context[0] or ['']))
        path = pathlib.Path(frame.filename).parent
    except:
        path = None
    finally:
        del stack

    return path


def get_local_config_path(variant):
    local_dir = get_caller_path() or pathlib.Path('.')
    path = local_dir / 'config' / f'{variant}.toml'
    if not path.exists():
        path = local_dir / 'config' / f'config.toml'
    return path


def Config(name, path=None, variant='config'):
    config_path = CONFIGDIR / name / f'{variant}.toml'
    if not config_path.exists():
        config_path.parent.mkdir(parents=True, exist_ok=True)
        local_config_path = path or get_local_config_path(variant)
        shutil.copy(local_config_path, config_path)

    config = addict.Dict(toml.loads(config_path.read_text()))
    return config


def update_config(name, path=None, variant='config'):
    config_path = CONFIGDIR / name / f'{variant}.toml'
    config = Config(name, path, variant)
    local_config = addict.Dict(toml.loads((path or get_local_config_path(variant)).read_text()))
    local_config.update(config)
    config_path.write_text(toml.dumps(local_config))



__version__ = '0.2.1'

from .config import Config, update_config
from .logging import Logger

config = None
logger = None


def start(name, config_path=None, config_variant='config'):
    global config, logger
    config = Config(name, config_path, variant=config_variant)
    logger = Logger(name)



from io import open

from setuptools import setup, find_packages

with open('kick/__init__.py', 'r') as f:
    for line in f:
        if line.startswith('__version__'):
            version = line.strip().split('=')[1].strip(' \'"')
            break
    else:
        version = '0.0.1'

with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

REQUIRES = [
    'addict',
    'toml',
    'daiquiri',
    'first'
]

setup(
    name='kick',
    version=version,
    description='',
    long_description=readme,
    author='Alin Panaitiu',
    author_email='alin.p32@gmail.com',
    maintainer='Alin Panaitiu',
    maintainer_email='alin.p32@gmail.com',
    url='https://github.com/alin23/kick',
    license='MIT/Apache-2.0',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=REQUIRES,
    tests_require=['coverage', 'pytest'],

    packages=find_packages(),
)
